SimpleDraftModel

Struct SimpleDraftModel 

pub struct SimpleDraftModel {
    pub tokens: Vec<TokenId>,
    pub probability: f32,
}
A mock draft model with a configurable token sequence and probability.

Fields

tokens: Vec<TokenId>

Tokens the draft model will propose, cycling if gamma > len.

probability: f32

Probability assigned to each drafted token.